AngleCubeMaps class

Constructors

AngleCubeMaps(AngleRenderer renderer)

Properties

cubemaps ↔ WeakMap
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
renderer AngleRenderer
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
get(Texture? texture) → Texture?
mapTextureMapping(Texture texture, int? mapping) → Texture
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onTextureDispose(dynamic event) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited