AngleObjects class

Constructors

AngleObjects(RenderingContext gl, AngleGeometries geometries, AngleAttributes attributes, AngleInfo info)

Properties

attributes AngleAttributes
getter/setter pair
geometries AngleGeometries
getter/setter pair
gl ↔ RenderingContext
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
info AngleInfo
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateMap → WeakMap
final

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onInstancedMeshDispose(dynamic event) → void
toString() String
A string representation of this object.
inherited
update(Object3D object) → BufferGeometry

Operators

operator ==(Object other) bool
The equality operator.
inherited