AngleProgramExtra mixin

Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
includePattern RegExp
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shaderChunkMap Map
final
unrollLoopPattern RegExp
final

Methods

fetchAttributeLocations(RenderingContext gl, Program program) Map<String, AttributeLocations>
filterEmptyLine(dynamic string) bool
generateCubeUVSize(Parameters parameters) Map<String, dynamic>?
generateDefines(dynamic defines) String
generateEnvMapBlendingDefine(Parameters parameters) String
generateEnvMapModeDefine(Parameters parameters) String
generateEnvMapTypeDefine(Parameters parameters) String
generatePrecision(Parameters parameters) String
generateShadowMapTypeDefine(Parameters parameters) String
generateVertexExtensions(Parameters parameters) String
getEncodingComponents(String colorSpace) List<String>
getShaderErrors(RenderingContext gl, AngleShader shader, dynamic type) String
getTexelEncodingFunction(String functionName, String encoding) String
getToneMappingFunction(dynamic functionName, dynamic toneMapping) String
handleSource(String? string, int errorLine) String
includeReplacer(dynamic match, dynamic include) String
loopReplacer(dynamic match, dynamic s, dynamic e, dynamic snippet) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replaceClippingPlaneNums(String string, Parameters parameters) String
replaceLightNums(String string, Parameters parameters) String
resolveIncludes(String string) String
toString() String
A string representation of this object.
inherited
unrollLoopPatternReplace(String string) String
unrollLoops(String string) String

Operators

operator ==(Object other) bool
The equality operator.
inherited