AnglePrograms class

Constructors

AnglePrograms(AngleRenderer renderer, AngleCubeMaps cubemaps, AngleCubeUVMaps cubeuvmaps, AngleExtensions extensions, AngleCapabilities capabilities, AngleBindingStates bindingStates, AngleClipping clipping)

Properties

bindingStates AngleBindingStates
getter/setter pair
capabilities AngleCapabilities
getter/setter pair
clipping AngleClipping
getter/setter pair
cubemaps AngleCubeMaps
getter/setter pair
cubeuvmaps AngleCubeUVMaps
getter/setter pair
extensions AngleExtensions
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
logarithmicDepthBuffer bool
getter/setter pair
precision String
getter/setter pair
programs List<AngleProgram>
getter/setter pair
renderer AngleRenderer
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shaderIDs Map<String, String>
final
vertexTextures bool
getter/setter pair

Methods

acquireProgram(Parameters parameters, String cacheKey) AngleProgram?
dispose() → void
getChannel(int value) String
getParameters(Material material, LightState lights, List<Light> shadows, Scene scene, Object3D object) → Parameters
getProgramCacheKey(Parameters parameters) String
getProgramCacheKeyBooleans(List array, Parameters parameters) → void
getProgramCacheKeyParameters(List array, Parameters parameters) → void
getUniforms(Material material) Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
releaseProgram(AngleProgram program) → void
releaseShaderCache(Material material) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited