AngleShadowMap class

Inheritance
  • Object
  • ShadowMap
  • AngleShadowMap

Constructors

AngleShadowMap(AngleRenderer _renderer, AngleObjects _objects, AngleCapabilities _capabilities)

Properties

autoUpdate bool
getter/setter pairinherited
enabled bool
getter/setter pairinherited
fullScreenMesh ↔ Mesh
getter/setter pairinherited
fullScreenTri ↔ BufferGeometry
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
needsUpdate bool
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ ShadowMap
getter/setter pairinherited
shadowMaterialHorizontal ↔ ShaderMaterial
getter/setter pairinherited
shadowMaterialVertical ↔ ShaderMaterial
getter/setter pairinherited
shadowSide Map<int, int>
finalinherited
type int
getter/setter pairinherited

Methods

dispose() → void
override
getDepthMaterial(Object3D object, Material material, Light light, double shadowCameraNear, double shadowCameraFar, int type) → Material
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(List<Light> lights, Object3D scene, Camera camera) → void
override
renderObject(Object3D object, Camera camera, Camera shadowCamera, Light light, int type) → void
override
toString() String
A string representation of this object.
inherited
vSMPass(LightShadow shadow, Camera camera) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited