AngleUniformsGroups class
Constructors
- AngleUniformsGroups(RenderingContext gl, AngleInfo info, AngleCapabilities capabilities, AngleState state)
Properties
- allocatedBindingPoints → Uint32List
-
latefinal
- buffers ↔ Map
-
getter/setter pair
- capabilities ↔ AngleCapabilities
-
getter/setter pair
- gl ↔ RenderingContext
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- info ↔ AngleInfo
-
getter/setter pair
- maxBindingPoints ↔ int
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ AngleState
-
getter/setter pair
- updateList ↔ Map
-
getter/setter pair
Methods
-
allocateBindingPointIndex(
) → int -
bind(
UniformsGroup uniformsGroup, AngleProgram? program) → void -
createBuffer(
UniformsGroup uniformsGroup) → Buffer -
dispose(
) → void -
getUniformSize(
dynamic value) → Map< String, int> -
hasUniformChanged(
dynamic uniform, int index, dynamic indexArray, dynamic cache) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onUniformsGroupsDispose(
dynamic event) → void -
prepareUniformsGroup(
UniformsGroup uniformsGroup) → AngleUniformsGroups -
toString(
) → String -
A string representation of this object.
inherited
-
update(
dynamic uniformsGroup, AngleProgram? program) → void -
updateBufferData(
Map uniformsGroup) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited