fromCubemap method
RenderTarget
fromCubemap(
- dynamic cubemap, [
- RenderTarget? renderTarget
- Generates a PMREM from an cubemap texture, which can be either LDR
- or HDR. The ideal input cube size is 256 x 256,
- as this matches best with the 256 x 256 cubemap output.
Implementation
/// * Generates a PMREM from an cubemap texture, which can be either LDR
/// * or HDR. The ideal input cube size is 256 x 256,
/// * as this matches best with the 256 x 256 cubemap output.
/// *
RenderTarget fromCubemap(cubemap, [RenderTarget? renderTarget]) {
return _fromTexture(cubemap, renderTarget);
}